$fn = $preview ? 32: 64;

//Parametric box design to fit pcb with sizing for board, component parts height and solder side height.
// adapted for curve tracer.
// by firepower9966 is licensed under the Creative Commons - Attribution - Non-Commercial - Share Alike license.


pcb_L=67.6;
pcb_W=17.6; 
wall=1.2; 		//wall thickness multiple of nozzle  size  (0.4)
base=1.6; 		//base thickness multiple of layer height (0.2)
lid=1.6; 			//lid thickness multiple of layer height  height (0.2)

pcb_part_H=15.8; 
pcb_H=0;
pcb_solder_H=1;

H=base+lid+pcb_part_H+pcb_H+pcb_solder_H;
L=pcb_L+wall*2;
W=pcb_W+wall*2;
echo("H=",H);
echo("L=",L);
echo("W=",W);


pillar=7;
radius=4;		//corner radius
gap = 0.3;		//tolerance depending on 3D printer and filament used

insert_D=4;
insert_H=7;

bnc_D=9;
bnc_gap=20;
banana_D=8;
banana_gap=19;

screw_D=3; 				//Screw Diameter
screw_head=5.6; 		//Screw Head Diameter
screw_head_H=2; 	//Screw Head Height

//Text
text_H=0.6;
font1="Noto Sans Math";     
font2="Arial:style=Bold";




		module roundBox(x, y, z, radius=2){
			hull(){
				translate([radius,radius,0])		cylinder(r=radius,h=z);
				translate([x-radius,radius,0])	cylinder(r=radius,h=z);
				translate([x-radius,y-radius,0])	cylinder(r=radius,h=z);
				translate([radius,y-radius,0])	cylinder(r=radius,h=z);
	}
}


	union(){
		difference(){
					union(){
					difference(){  // box
						roundBox(W,L,H,radius);
							translate([wall*2,wall*2,base]) 				roundBox(pcb_W-wall*2,pcb_L-wall*2,pcb_part_H+pcb_H+pcb_solder_H, radius-wall);
							translate([wall,wall,base+pcb_part_H]) 	roundBox(pcb_W,pcb_L,lid+pcb_H+pcb_solder_H+gap, radius-wall);
									}
			//pillar
			translate([0, 0, base]) 																	roundBox(pillar+wall, pillar+wall, pcb_part_H, radius);
			translate([pcb_W+wall-pillar, pcb_L+wall-pillar, base]) roundBox(pillar+wall, pillar+wall, pcb_part_H, radius);
			translate([pcb_W+wall-pillar, 0,base]) 									roundBox(pillar+wall, pillar+wall, pcb_part_H, radius);
			translate([0, pcb_L+wall-pillar, base]) 									roundBox(pillar+wall, pillar+wall, pcb_part_H, radius);
						}
        //insert hole
        translate([pillar/2+wall,pillar/2+wall,base+pcb_part_H-insert_H]) 							cylinder(d=insert_D+gap,h=insert_H);
        translate([pcb_W+wall-pillar/2,pcb_L+wall-pillar/2,base+pcb_part_H-insert_H]) 	cylinder(d=insert_D+gap   ,h=insert_H);
		translate([pcb_W+wall-pillar/2,wall+pillar/2,base+pcb_part_H-insert_H]) 				cylinder(d=insert_D+gap,h=      insert_H);
		translate([wall+pillar/2,pcb_L+wall-pillar/2,base+pcb_part_H-insert_H]) 				cylinder(d=insert_D+gap,h=insert_H);
       
        //bnc hole
        translate([0, L/2, H/2])        rotate([0,90,0])    cylinder(10, d=bnc_D+gap, center=true); 
        translate([0, L/2+20, H/2]) rotate([0,90,0])    cylinder(10, d=bnc_D+gap, center=true); 
        translate([0, L/2-20, H/2])  rotate([0,90,0])    cylinder(10, d=bnc_D+gap, center=true); 
          
        //bnc hole
        translate([W, L/2+19/2, H/2])    rotate([0,90,0])  cylinder(10, d=banana_D+gap, center=true); 
        translate([W, L/2-19/2, H/2])     rotate([0,90,0])  cylinder(10, d=banana_D+gap, center=true); 
		
	
	//	un/comment if you want text on base or lid
	//	Text on base so you dont have screw holes visable and more room to text
	/*	translate([1.5, L/2, text_H])  				rotate([180,0,90]) 	linear_extrude(1)	text("Y", 			halign="center", 							font = font1 ,	size=5);
		translate([1.5, L/2-20, text_H]) 		rotate([180,0,90]) 	linear_extrude(1)	text("X", 			halign="center", 							font = font1, 	size=5);
		translate([0.5, L/2+20, text_H])  		rotate([180,0,90]) 	linear_extrude(1)	text("∿", 			halign="center", 							font = font1, 	size=7);
		translate([W/2-1.7, L/2, text_H])  	rotate([180,0,90]) 	linear_extrude(1)	text("DSO CURVE TRACER", halign="center", font = font2,	size=3);
		translate([W/2+4.2, L/2, text_H])		rotate([180,0,90]) 	linear_extrude(1)	text("⇖    ⇗", 	halign="center", 							font = font1,	size=5);
		translate([W/2+3, L/2, text_H])			rotate([180,0,90]) 	linear_extrude(1)	text("⍰", 		halign="center", 							font = font1,	size=5);
	*/
	
		
				}
		}

width = pcb_W-gap;
length = pcb_L-gap;
holed = pillar-gap/2;
	
	module screwLid(){
					difference(){
								union(){
								//lid
								translate([0,0,0]) 											roundBox(width,length,lid,radius-wall);
			                    //pillar
								translate([0,0,lid]) 											roundBox(pillar,pillar,pcb_solder_H,radius-wall);
								translate([width-pillar,0,lid]) 							roundBox(pillar,pillar,pcb_solder_H,radius-wall);
								translate([width-pillar,length-pillar,lid]) 		roundBox(pillar,pillar,pcb_solder_H,radius-wall);
								translate([0,length-pillar,lid])  						roundBox(pillar,pillar,pcb_solder_H,radius-wall);
								//rib
								translate([0,radius,lid])										cube([wall,length-radius*2,pcb_solder_H]);
								translate([width-wall,radius,lid])						cube([wall,length-radius*2,pcb_solder_H]);
								translate([radius,0,lid]) 										cube([width-radius*2,wall,pcb_solder_H]);
								translate([radius,length-wall,lid])						cube([width-radius*2,wall,pcb_solder_H]);
										}
            
				//screw hole
				translate([pillar/2-gap/2, pillar/2-gap/2, 0]) 							cylinder(d=screw_D+gap,h=lid+pcb_solder_H);
				translate([width-pillar/2+gap/2, pillar/2-gap/2, 0]) 					cylinder(d=screw_D+gap,h=lid+pcb_solder_H);
				translate([width-pillar/2+gap/2, length-pillar/2+gap/2, 0]) 	cylinder(d=screw_D+gap,h=lid+pcb_solder_H);
				translate([pillar/2-gap/2, length-pillar/2+gap/2, 0]) 				cylinder(d=screw_D+gap,h=lid+pcb_solder_H);
  
				//un/comment for type of screw used
				//countersunk head screw hole
				translate([pillar/2-gap/2, pillar/2-gap/2, 0]) 							cylinder(d1=screw_head+gap,d2=screw_D+gap,h=screw_head_H);
				translate([width-pillar/2+gap/2, pillar/2-gap/2, 0]) 					cylinder(d1=screw_head+gap,d2=screw_D+gap,h=screw_head_H);
				translate([width-pillar/2+gap/2, length-pillar/2+gap/2, 0]) 	cylinder(d1=screw_head+gap,d2=screw_D+gap,h=screw_head_H);
				translate([pillar/2-gap/2, length-pillar/2+gap/2, 0]) 				cylinder(d1=screw_head+gap,d2=screw_D+gap,h=screw_head_H);
          
				//cap head screw  hole
      /*    	translate([pillar/2-gap/2, pillar/2-gap/2, 0]) cylinder(d=screw_head+gap,h=screw_head_H);
				translate([width-pillar/2+gap/2, pillar/2-gap/2, 0]) cylinder(d=screw_head+gap,h=screw_head_H);
				translate([width-pillar/2+gap/2, length-pillar/2+gap/2, 0]) cylinder(d=screw_head+gap,h=screw_head_H);
				translate([pillar/2-gap/2, length-pillar/2+gap/2, 0]) cylinder(d=screw_head+gap,h=screw_head_H);
     */     
	 
	 //	un/comment if you want text on base or lid
	 //	Text on lid allows you to quickly print new lids with new text.
			translate([.6, L/2-wall*2, text_H])  			rotate([180,0,90]) 	linear_extrude(1)	text("Y", 			halign="center", 							font = font1 ,	size=5);
			translate([.6, L/2-wall*2-20, text_H]) 		rotate([180,0,90]) 	linear_extrude(1)	text("X", 			halign="center", 							font = font1, 	size=5);
			translate([-.3, L/2-wall*2+20, text_H])  	rotate([180,0,90]) 	linear_extrude(1)	text("∿", 			halign="center", 							font = font1, 	size=7);
			translate([W/2-3.5, L/2-wall*2, text_H])  	rotate([180,0,90]) 	linear_extrude(1)	text("DSO CURVE TRACER", halign="center", font = font2,	size=3);
			translate([W/2+2, L/2-wall*2, text_H])		rotate([180,0,90]) 	linear_extrude(1)	text("⇖    ⇗", 	halign="center", 							font = font1,	size=5);
			translate([W/2+1, L/2-wall*2, text_H])		rotate([180,0,90]) 	linear_extrude(1)	text("⍰", 		halign="center", 							font = font1,	size=5);
		
          
						}
					}

			translate([W+wall*2,wall,0]) screwLid();